@@ -37,7 +37,11 @@ pl_get_baf = function(abbr, geographies=NULL, cache_to=NULL, refresh=FALSE) {
     zip_url = str_glue("https://www2.census.gov/geo/docs/maps-data/data/baf2020/{base_name}.zip")
     zip_path = withr::local_tempfile(fileext ="baf")
     zip_dir = dirname(zip_path)
-    download_census(zip_url, zip_path)
+    success = download_census(zip_url, zip_path)
+    if (!success) {
+        message("Download did not succeed. Try again.")
+        return(NULL)
+    }
 
     files = utils::unzip(zip_path, list=TRUE)$Name
     utils::unzip(zip_path, exdir=zip_dir)
